SQL
===

.. autofunction:: daft.sql

.. autofunction:: daft.sql_expr

SQL Functions
-------------

This is a full list of functions that can be used from within SQL.


.. sql-autosummary::
    :toctree: doc_gen/sql_funcs
